/*
Google Music Frame :: Window

This file contains main window.

Copyright 2011 Jiří Janoušek <janousek.jiri@gmail.com>

This program is free software: you can redistribute it and/or modify it 
under the terms of the GNU General Public License version 3, as published 
by the Free Software Foundation.

This program is distributed in the hope that it will be useful, but 
WITHOUT ANY WARRANTY; without even the implied warranties of 
MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along 
with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

using Gtk;
using Fenryxo.Logger;

namespace GMF{
	
	
	public class TroubleshootingWindow : Gtk.Window{
		/// Troubleshooting dialog title
		private const string TITLE = _("Troubleshooting");
		private Application app;
		private Box box;
		
		private static TroubleshootingWindow win;
		
		public static void display(Application app){
			if(TroubleshootingWindow.win == null){
				TroubleshootingWindow.win = new TroubleshootingWindow(app);
			}
			TroubleshootingWindow.win.show_all();
			TroubleshootingWindow.win.present();
		}
		
		/**
		 * Constructs new main window
		 * 
		 * @param app Application object
		 */
		private TroubleshootingWindow(Application app){
			this.app = app;
			this.position = WindowPosition.CENTER;
			this.title = TITLE;
			try {
				this.icon = IconTheme.get_default().load_icon(this.app.icon, 48, 0);
			}
			catch(Error e){
				log_warning("Unable to load application icon.");
			}
			
			
			this.box = new Gtk.VBox(false, 10);
			this.box.border_width = 5;
			Button button;
			/// Troubleshooting dialog
			button = new Button.with_label(_("Purge cookies"));
			button.clicked.connect(this.app.purge_cookies);
			this.box.pack_start(button, false, false);
			/// Troubleshooting dialog
			button = new Button.with_label(_("Purge album art cache"));
			button.clicked.connect(this.app.purge_album_art);
			this.box.pack_start(button, false, false);
#if LIBSOUP_CACHE
			/// Troubleshooting dialog
			button = new Button.with_label(_("Purge browser cache"));
			button.clicked.connect(this.app.purge_browser);
			this.box.pack_start(button, false, false);
#endif
			this.add(this.box);
			this.box.show_all();
		}
		
		public override bool delete_event(Gdk.Event event){
			TroubleshootingWindow.win = null;
			return false;
		}
	}
}
